@@ -65,7 +65,7 @@ const gchar *exchange_delegates_user_folder_names[] = {
 };
 
 /* To translators: The folder names to be displayed in the message being
-   sent to the delegatee.
+ * sent to the delegatee.
 */
 static const gchar *folder_names_for_display[] = {
 	N_("Calendar"), N_("Tasks"), N_("Inbox"), N_("Contacts")
@@ -78,8 +78,10 @@ enum {
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
-#define PARENT_TYPE G_TYPE_OBJECT
-static GObjectClass *parent_class = NULL;
+G_DEFINE_TYPE (
+	ExchangeDelegatesUser,
+	exchange_delegates_user,
+	G_TYPE_OBJECT)
 
 static void
 finalize (GObject *object)
@@ -95,14 +97,15 @@ finalize (GObject *object)
 	if (user->sid)
 		g_object_unref (user->sid);
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (exchange_delegates_user_parent_class)->finalize (object);
 }
 
 static void
-class_init (GObjectClass *object_class)
+exchange_delegates_user_class_init (ExchangeDelegatesUserClass *class)
 {
-	parent_class = g_type_class_ref (PARENT_TYPE);
+	GObjectClass *object_class;
 
+	object_class = G_OBJECT_CLASS (class);
 	object_class->finalize = finalize;
 
 	/* signals */
@@ -116,7 +119,10 @@ class_init (GObjectClass *object_class)
 			      G_TYPE_NONE, 0);
 }
 
-E2K_MAKE_TYPE (exchange_delegates_user, ExchangeDelegatesUser, class_init, NULL, PARENT_TYPE)
+static void
+exchange_delegates_user_init (ExchangeDelegatesUser *user)
+{
+}
 
 static inline gboolean
 is_delegate_role (E2kPermissionsRole role)
@@ -128,7 +134,8 @@ is_delegate_role (E2kPermissionsRole role)
 }
 
 static void
-set_perms (GtkWidget *combobox, E2kPermissionsRole role)
+set_perms (GtkWidget *combobox,
+           E2kPermissionsRole role)
 {
 	if (!is_delegate_role (role)) {
 		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combobox), _("Custom"));
@@ -139,7 +146,8 @@ set_perms (GtkWidget *combobox, E2kPermissionsRole role)
 }
 
 static void
-parent_window_destroyed (gpointer dialog, GObject *where_parent_window_was)
+parent_window_destroyed (gpointer dialog,
+                         GObject *where_parent_window_was)
 {
 	gtk_dialog_response (dialog, GTK_RESPONSE_CANCEL);
 }
@@ -154,20 +162,21 @@ map_to_full_role_name (E2kPermissionsRole role_nam)
 	switch (role_nam) {
 		case E2K_PERMISSIONS_ROLE_EDITOR:
 			/* To Translators: The following is a type of permissions that can be assigned by a user to his/her folders. */
-			role_name = g_strdup (_("Editor (read, create, edit)"));
+			role_name = _("Editor (read, create, edit)");
 			break;
 
 		case E2K_PERMISSIONS_ROLE_AUTHOR:
 			/* To Translators: The following is a type of permissions that can be assigned by a user to his/her folders. */
-			role_name = g_strdup (_("Author (read, create)"));
+			role_name = _("Author (read, create)");
 			break;
 
 		case E2K_PERMISSIONS_ROLE_REVIEWER:
 			/* To Translators: The following is a type of permissions that can be assigned by a user to his/her folders. */
-			role_name = g_strdup (_("Reviewer (read-only)"));
+			role_name = _("Reviewer (read-only)");
 			break;
 
-		default: role_name = g_strdup (_("None"));
+		default:
+			role_name = _("None");
 			 break;
 	}
 
@@ -175,19 +184,21 @@ map_to_full_role_name (E2kPermissionsRole role_nam)
 }
 
 static void
-em_utils_delegates_done (GObject *source_object, GAsyncResult *res, gpointer user_data)
+em_utils_delegates_done (GObject *source_object,
+                         GAsyncResult *res,
+                         gpointer user_data)
 {
 	EShell *shell;
 	EShellBackend *shell_backend;
-	EMailSession *session;
+	EMailBackend *mail_backend;
 
 	/* XXX Dig up the EMailSession from the default EShell. */
 	shell = e_shell_get_default ();
 	shell_backend = e_shell_get_backend_by_name (shell, "mail");
-	session = e_mail_backend_get_session (E_MAIL_BACKEND (shell_backend));
+	mail_backend = E_MAIL_BACKEND (shell_backend);
 
 	if (e_mail_folder_append_message_finish (CAMEL_FOLDER (source_object), res, NULL, NULL))
-		mail_send (session);
+		mail_send (mail_backend);
 }
 
 /**
@@ -202,8 +213,8 @@ em_utils_delegates_done (GObject *source_object, GAsyncResult *res, gpointer use
  **/
 gboolean
 exchange_delegates_user_edit (ExchangeAccount *account,
-			     ExchangeDelegatesUser *user,
-			     GtkWidget *parent_window)
+                              ExchangeDelegatesUser *user,
+                              GtkWidget *parent_window)
 {
 	gchar *title;
 	gint button, i;
@@ -231,7 +242,7 @@ exchange_delegates_user_edit (ExchangeAccount *account,
 
 	delegate_permissions = gtk_dialog_new_with_buttons (
 		/* Translators: "Delegate Permissions" refers to the permissions on the delegator's folders
-		   that the delegatee would receive */
+		 * that the delegatee would receive */
 		_("Delegate Permissions"),
 		NULL,
 		GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -369,11 +380,11 @@ exchange_delegates_user_edit (ExchangeAccount *account,
 	g_object_weak_ref (G_OBJECT (parent_window),
 			   parent_window_destroyed, delegate_permissions);
 	g_object_add_weak_pointer (G_OBJECT (parent_window),
-				   (gpointer*)&parent_window);
+				   (gpointer *) &parent_window);
 	button = gtk_dialog_run (GTK_DIALOG (delegate_permissions));
 	if (parent_window) {
 		g_object_remove_weak_pointer (G_OBJECT (parent_window),
-					      (gpointer *)&parent_window);
+					      (gpointer *) &parent_window);
 		g_object_weak_unref (G_OBJECT (parent_window),
 				     parent_window_destroyed, delegate_permissions);
 	}
@@ -397,7 +408,7 @@ exchange_delegates_user_edit (ExchangeAccount *account,
 	}
 
 	/* The following piece of code is used to construct a mail message to be sent to a Delegate
-	   summarizing all the permissions set for him on the user's various folders.
+	 * summarizing all the permissions set for him on the user's various folders.
 	*/
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (delegate_mail)) == TRUE) {
 		if (button == GTK_RESPONSE_OK) {
@@ -413,14 +424,13 @@ exchange_delegates_user_edit (ExchangeAccount *account,
 			CamelFolder *out_folder;
 			CamelMessageInfo *info;
 			gchar *self_address, *delegate_mail_subject;
-			gchar *role_name;
-			GString *role_name_final;
+			GString *html_buffer;
 
 			const gchar *recipient_address;
 			const gchar *delegate_exchange_dn;
 			const gchar *msg_part1 = NULL, *msg_part2 = NULL;
 
-			role_name_final = g_string_new ("");
+			html_buffer = g_string_sized_new (1024);
 
 			self_address = g_strdup (exchange_account_get_email_id (account));
 
@@ -435,10 +445,9 @@ exchange_delegates_user_edit (ExchangeAccount *account,
 			camel_content_type_set_param (type, "format", "flowed");
 			camel_data_wrapper_set_mime_type_field (delegate_mail_text, type);
 			camel_content_type_unref (type);
-			stream = camel_stream_mem_new ();
 
 			/* To translators: This is a part of the message to be sent to the delegatee
-			   summarizing the permissions assigned to him.
+			 * summarizing the permissions assigned to him.
 			*/
 			msg_part1 = _("This message was sent automatically by Evolution to inform you that you have been "
 					"designated as a delegate. You can now send messages on my behalf.");
@@ -447,37 +456,50 @@ exchange_delegates_user_edit (ExchangeAccount *account,
 			*/
 			msg_part2 = _("You have been given the following permissions on my folders:");
 
-			camel_stream_printf (stream,
-				"<html><body><p>%s<br><br>%s</p><table border = 0 width=\"40%%\">", msg_part1, msg_part2);
+			g_string_append_printf (
+				html_buffer,
+				"<html><body><p>%s<br><br>%s</p>"
+				"<table border = 0 width=\"40%%\">",
+				msg_part1, msg_part2);
+
 			for (i = 0; i < EXCHANGE_DELEGATES_LAST; i++) {
+				const gchar *role_name;
+
 				combobox = comboboxes[i];
 				role = e_dialog_combo_box_get (combobox, exchange_perm_map);
-				role_name = g_strdup (map_to_full_role_name (role));
+				role_name = map_to_full_role_name (role);
 				g_string_append_printf (
-					role_name_final,
+					html_buffer,
 					"<tr><td>%s:</td><td>%s</td></tr>",
 					folder_names_for_display[i], role_name);
 			}
 
-			camel_stream_printf (stream, "%s</table>", role_name_final->str);
+			g_string_append (html_buffer, "</table");
 
 			if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (see_private_checkbox)) == TRUE) {
-				/* To translators: This message is included if the delegatee has been given access
-				   to the private items.
-				*/
-				camel_stream_printf (stream, "<br>%s", _("You are also permitted "
-							"to see my private items."));
+				/* Translators: This message is included if
+				 * the delegatee has been given access to the
+				 * private items. */
+				g_string_append_printf (
+					html_buffer, "<br>%s",
+					_("You are also permitted to see "
+					  "my private items."));
 			}
 			else
-				/* To translators: This message is included if the delegatee has not been given access
-				   to the private items.
-				*/
-				camel_stream_printf (stream, "<br>%s", _("However, you are not permitted "
-							 "to see my private items."));
+				/* Translators: This message is included if
+				 * the delegatee has not been given access
+				 * to the private items. */
+				g_string_append_printf (
+					html_buffer, "<br>%s",
+					_("However, you are not permitted "
+					  "to see my private items."));
+
+			stream = camel_stream_mem_new ();
+			camel_stream_write (
+				stream, html_buffer->str,
+				html_buffer->len, NULL, NULL);
 			camel_data_wrapper_construct_from_stream_sync (
 				delegate_mail_text, stream, NULL, NULL);
-			g_free (role_name);
-			g_string_free (role_name_final, TRUE);
 			g_object_unref (stream);
 
 			part = camel_mime_part_new ();
@@ -544,6 +566,8 @@ exchange_delegates_user_edit (ExchangeAccount *account,
 			e_mail_folder_append_message (out_folder, delegate_mail, info, 0, NULL, em_utils_delegates_done, NULL);
 			camel_message_info_free (info);
 			g_object_unref (delegate_mail);
+
+			g_string_free (html_buffer, TRUE);
 		}
 
 	}
@@ -601,8 +625,8 @@ exchange_delegates_user_new (const gchar *display_name)
  **/
 ExchangeDelegatesUser *
 exchange_delegates_user_new_from_gc (E2kGlobalCatalog *gc,
-				    const gchar *email,
-				    GByteArray *creator_entryid)
+                                    const gchar *email,
+                                    GByteArray *creator_entryid)
 {
 	E2kGlobalCatalogStatus status;
 	E2kGlobalCatalogEntry *entry;
@@ -629,7 +653,7 @@ exchange_delegates_user_new_from_gc (E2kGlobalCatalog *gc,
 		p--;
 	g_byte_array_append (user->entryid, creator_entryid->data,
 			     p - creator_entryid->data + 1);
-	g_byte_array_append (user->entryid, (guint8*) entry->legacy_exchange_dn,
+	g_byte_array_append (user->entryid, (guint8 *) entry->legacy_exchange_dn,
 			     strlen (entry->legacy_exchange_dn));
 	g_byte_array_append (user->entryid, (guint8*)"", 1);
 
